# Creating Custom Transformation Templates
### On this page
  * [Introduction](https://help.sap.com/docs/leanix/ea/creating-custom-transformation-templates#introduction)
  * [Creating Transformation Templates](https://help.sap.com/docs/leanix/ea/creating-custom-transformation-templates#creating-transformation-templates)
  * [Configuring Template Fields](https://help.sap.com/docs/leanix/ea/creating-custom-transformation-templates#configuring-template-fields)
  * [Predefining the Scope of Available Fact Sheets for Users](https://help.sap.com/docs/leanix/ea/creating-custom-transformation-templates#predefining-the-scope-of-available-fact-sheets-for-users)


Customize and create transformation templates to fit your needs: add impacts, adjust fields, show/hide fact sheets, and make it user-friendly.
